==> tknodesystem-0.1.tar.gz: tknodesystem-0.1/README.md <==
![title](https://github.com/Akascape/TkNodeSystem/assets/89206401/a84cb60a-cc6f-4609-8452-3ff4fcd0c46b)

**Simple Node System (DAG) in tkinter python!**

## Feature
- Lightweight library
- Easy to install and use
- Multiple nodes and inputs
- **Save/Load** node trees
- Canvas with **drag and zoom** ability
- Customizable options
- Built-in **Node menu**

## Installation
```
pip install tknodesystem
```
### [<img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/Akascape/TkNodeSystem?&color=cyan&label=Download%20Source%20Code&logo=Python&logoColor=yellow&style=for-the-badge"  width="400">](https://github.com/Akascape/TkNodeSystem/archive/refs/heads/main.zip)

### Requirements
- tkinter
- customtkinter _(for the node menu)_

## Overview:

- Node Types

![node_types](https://github.com/Akascape/TkNodeSystem/assets/89206401/cccf82dd-8207-4894-9e9e-ef240e511d85)

- Node Menu

![node_menu](https://github.com/Akascape/TkNodeSystem/assets/89206401/0ba5ba42-4787-4b94-8b40-682084df2e80)

- Node Canvas

![canvas_types](https://github.com/Akascape/TkNodeSystem/assets/89206401/d5568962-50c0-404c-bf71-79d66f79e3b7)

## Documentation
Full documentation can be found in the **Wiki** page

[<img src="https://img.shields.io/badge/View-Docs-informational?&color=yellow&style=for-the-badge" width="150">](https://github.com/Akascape/TkNodeSystem/wiki)

## Examples
Examples are given in the `examples` folder
![Example App](https://github.com/Akascape/TkNodeSystem/assets/89206401/ea818333-c979-4402-bc7c-8850930dc087)

### Bug Fixes
This library is at **experimental stage**, so there must be some bugs which can appear randomly.

**So, please report the bugs at the issues/discussions. A pull request is always welcomed :)**

==> tknodesystem-0.3.tar.gz: tknodesystem-0.3/README.md <==
![title](https://github.com/Akascape/TkNodeSystem/assets/89206401/a84cb60a-cc6f-4609-8452-3ff4fcd0c46b)

**Simple Node System (DAG) in tkinter python!**

## Feature
- Lightweight library
- Easy to install and use
- Multiple nodes and inputs
- **Save/Load** node trees
- Canvas with **drag and zoom** ability
- Customizable options
- Built-in **Node menu**

## Installation
```
pip install tknodesystem
```
### [<img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/Akascape/TkNodeSystem?&color=cyan&label=Download%20Source%20Code&logo=Python&logoColor=yellow&style=for-the-badge"  width="400">](https://github.com/Akascape/TkNodeSystem/archive/refs/heads/main.zip)

[![PyPI](https://img.shields.io/pypi/v/tknodesystem)](https://pypi.org/project/tknodesystem)
[![Downloads](https://static.pepy.tech/badge/tknodesystem)](https://pepy.tech/project/tknodesystem)
![Platform](https://img.shields.io/powershellgallery/p/Pester?color=blue)

### Requirements
- tkinter
- customtkinter _(for the node menu)_

## Overview

- Node Types

![node_types](https://github.com/Akascape/TkNodeSystem/assets/89206401/cccf82dd-8207-4894-9e9e-ef240e511d85)

- Node Menu

![node_menu](https://github.com/Akascape/TkNodeSystem/assets/89206401/0ba5ba42-4787-4b94-8b40-682084df2e80)

- Node Canvas

![canvas_types](https://github.com/Akascape/TkNodeSystem/assets/89206401/d5568962-50c0-404c-bf71-79d66f79e3b7)

## Documentation
Full documentation can be found in the **Wiki** page

[<img src="https://img.shields.io/badge/View-Docs-informational?&color=c8ab09&style=for-the-badge" width="150">](https://github.com/Akascape/TkNodeSystem/wiki)

## Examples
Examples are given in the `examples` folder
![Example App](https://github.com/Akascape/TkNodeSystem/assets/89206401/ea818333-c979-4402-bc7c-8850930dc087)

### Bug Fixes
This library is at **experimental stage**, so there must be some bugs which can appear randomly.

**So, please report the bugs at the issues/discussions tab. A pull request is always welcomed :)**
